#
# spec file for package python-warlock
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-warlock
Version:        2.0.1
Release:        2.4
Summary:        Python object model built on top of JSON schema
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://github.com/bcwaldon/warlock
Source:         https://github.com/bcwaldon/warlock/archive/%{version}.tar.gz#/warlock-%{version}.tar.gz
BuildRequires:  %{python_module jsonpatch >= 1}
BuildRequires:  %{python_module jsonschema >= 4}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module poetry-core}
BuildRequires:  %{python_module pytest}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-jsonpatch >= 1
Requires:       python-jsonschema >= 4
BuildArch:      noarch
%python_subpackages

%description
Build self-validating python objects using JSON schemas.

%prep
%setup -q -n warlock-%{version}
rm pytest.ini

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%doc README.md
%license LICENSE
%{python_sitelib}/warlock
%{python_sitelib}/warlock-%{version}.dist-info

%changelog
* Tue Sep 26 2023 Ben Greiner <code@bnavigator.de>
- Fix dependencies and remove deprecated python packaging patterns
* Fri Oct 14 2022 pgajdos@suse.com
- version update to 2.0.1
  Added
  * Meta: Locked dependencies via poetry.lock file in version control. #44
  * Meta: Add pre-commit config to enforce code styling and file formatting. #43
  * Meta: Add tox config for test automation across Python versions. #47
  * Tests for DeprecationWarnings issued for Model.changes. #46
  * Cache the validator instance to speedup schema validation process. #55
  * Support for jsonschema 4.x. #65
  * Support for Python 3.9, 3.10. #65
  Fixed
  * Fixed DeprecationWarnings for using assertEquals in tests. #45
  Changed
  * Meta: Replace setuptools with poetry for packaging and dependency management. #35
  * Changed behavior of model_factory back to pre-1.3 call signature. #39
  * Meta: Switched build backend from poetry to poetry-core. #66
  Removed
  * Support for Python 3.4 (EOL). #44
  * Support for Python 3.5, 3.6 (EOL). #65
  * Support for Python 2.7 (EOL by 2019-01-01). #48
* Wed May 25 2022 Matej Cepl <mcepl@suse.com>
- Skipped test_recursive_models because the package is
  incompatible with jsonschema < 4 (gh#bcwaldon/warlock#64).
* Tue Sep 17 2019 John Vandenberg <jayvdb@gmail.com>
- Re-activate test suite using GitHub tarball which includes
  a setup.py
* Fri May 24 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.3.3:
  * README failed parsing in non utf-8 environments. Enforce encoding. #37
  * Move unittests to tests/ directory
  * Upstream no longer ships tests on pypi
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Tue Nov 14 2017 dmueller@suse.com
- update to 1.3.0:
  * Allow resolver to be set in model
  * flake8 compliance
* Wed Aug 23 2017 tbechtold@suse.com
- convert to singlespec
* Tue Nov 15 2016 dmueller@suse.com
- update to 1.2.0
* Tue Sep 16 2014 tbechtold@suse.com
- update to version 1.1.0:
  * Bump version to 1.1.0
  * Merge pull request #12 from apevec/master
  * LICENSE.txt was missing in the source tarball
  * Merge pull request #11 from isethi/validation
  * Add description to exception messages
  * Add python3 support
- Add python-to as BuildRequires and Requires.
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Wed Jul  3 2013 dmueller@suse.com
- update to 1.0.1:
  - drop allow-jsonschema-3.diff
* Sat Jun 22 2013 dmueller@suse.com
- add allow-jsonschema-3.diff
* Mon Apr 29 2013 dmueller@suse.com
- update to 1.0.0:
  * stable release
* Mon Feb 25 2013 saschpe@suse.de
- Allow jsonschema==1.0 too
* Fri Feb 22 2013 saschpe@suse.de
- Update to version 0.8.1:
  + Upstream provides no changelog
- LICENSE isn't part of upstream sources anymore
* Thu Nov 22 2012 saschpe@suse.de
- Update to version 0.6.0:
  + Upstream provides no changelog
* Thu Jul 26 2012 saschpe@suse.de
- Initial version
